# Copyright 2024 Cisco Systems, Inc. and its affiliates
from __future__ import annotations

from typing import TYPE_CHECKING, Optional

from catalystwan.abc import RequestAdapterInterface

if TYPE_CHECKING:
    from .schema.schema_builder import SchemaBuilder


class DhcpServerBuilder:
    """
    Builds and executes requests for operations under /v1/feature-profile/sdwan/service/dhcp-server
    """

    def __init__(self, request_adapter: RequestAdapterInterface) -> None:
        self._request_adapter = request_adapter

    def get_dhcp_server_profile_parcel_for_service(self, service_id: str, **kw) -> str:
        """
        Get Dhcp Server Profile Parcels for Service feature profile

        :param service_id: Feature Profile ID
        :returns: str
        """
        params = {
            "serviceId": service_id,
        }
        return self._request_adapter.request(
            "GET",
            "/dataservice/v1/feature-profile/sdwan/service/{serviceId}/dhcp-server",
            return_type=str,
            params=params,
            **kw,
        )

    def create_dhcp_server_profile_parcel_for_service(
        self, service_id: str, payload: Optional[str] = None, **kw
    ) -> str:
        """
        Create a Dhcp Server Profile Parcel for Service feature profile

        :param service_id: Feature Profile ID
        :param payload: Dhcp Server Profile Parcel
        :returns: str
        """
        params = {
            "serviceId": service_id,
        }
        return self._request_adapter.request(
            "POST",
            "/dataservice/v1/feature-profile/sdwan/service/{serviceId}/dhcp-server",
            return_type=str,
            params=params,
            payload=payload,
            **kw,
        )

    def get_dhcp_server_profile_parcel_by_parcel_id_for_service(
        self, service_id: str, dhcp_server_id: str, **kw
    ) -> str:
        """
        Get Dhcp Server Profile Parcel by parcelId for Service feature profile

        :param service_id: Feature Profile ID
        :param dhcp_server_id: Profile Parcel ID
        :returns: str
        """
        params = {
            "serviceId": service_id,
            "dhcpServerId": dhcp_server_id,
        }
        return self._request_adapter.request(
            "GET",
            "/dataservice/v1/feature-profile/sdwan/service/{serviceId}/dhcp-server/{dhcpServerId}",
            return_type=str,
            params=params,
            **kw,
        )

    def edit_dhcp_server_profile_parcel_for_service(
        self, service_id: str, dhcp_server_id: str, payload: Optional[str] = None, **kw
    ) -> str:
        """
        Update a Dhcp Server Profile Parcel for Service feature profile

        :param service_id: Feature Profile ID
        :param dhcp_server_id: Profile Parcel ID
        :param payload: Dhcp Server Profile Parcel
        :returns: str
        """
        params = {
            "serviceId": service_id,
            "dhcpServerId": dhcp_server_id,
        }
        return self._request_adapter.request(
            "PUT",
            "/dataservice/v1/feature-profile/sdwan/service/{serviceId}/dhcp-server/{dhcpServerId}",
            return_type=str,
            params=params,
            payload=payload,
            **kw,
        )

    def delete_dhcp_server_profile_parcel_for_service(
        self, service_id: str, dhcp_server_id: str, **kw
    ):
        """
        Delete a Dhcp Server Profile Parcel for Service feature profile

        :param service_id: Feature Profile ID
        :param dhcp_server_id: Profile Parcel ID
        :returns: None
        """
        params = {
            "serviceId": service_id,
            "dhcpServerId": dhcp_server_id,
        }
        return self._request_adapter.request(
            "DELETE",
            "/dataservice/v1/feature-profile/sdwan/service/{serviceId}/dhcp-server/{dhcpServerId}",
            params=params,
            **kw,
        )

    @property
    def schema(self) -> SchemaBuilder:
        """
        The schema property
        """
        from .schema.schema_builder import SchemaBuilder

        return SchemaBuilder(self._request_adapter)
